@@ -1,59 +1,59 @@
 $VAR1 = {
-          'htmlright' => '2',
-          'mod' => 'n',
-          'config' => '/var/www/cgi-bin/config/settings.pl',
-          'translate' => '/var/www/cgi-bin/config/translate.pl',
-          'language' => 'en',
-          'database' => {
-                          'host' => 'localhost',
-                          'password' => '',
-                          'user' => 'root',
-                          'CurrentHost' => 'localhost',
-                          'CurrentPass' => '',
-                          'name' => 'MySQLAdmin',
-                          'CurrentDb' => 'MySQLAdmin',
-                          'CurrentUser' => 'root'
-                        },
-          'files' => {
-                       'group' => 'lze',
-                       'owner' => 'lze',
-                       'chmod' => '0755'
-                     },
-          'news' => {
-                      'captcha' => 3,
-                      'right' => 5,
-                      'messages' => '5'
-                    },
-          'session' => '/var/www/cgi-bin/config/session.pl',
-          'actions' => '/var/www/cgi-bin/config/actions.pl',
-          'saveTranslate' => '0',
-          'defaultAction' => 'ShowDatabases',
-          'uploads' => {
-                         'chmod' => 438,
-                         'enabled' => 1,
-                         'maxlength' => '2100000000000000',
-                         'path' => '/var/www/htdocs//download',
-                         'right' => 2
-                       },
-          'admin' => {
-                       'password' => 'testpass'
-                     },
           'floodtime' => 10,
-          'size' => '16',
+          'actions' => '/var/www/cgi-bin/config/actions.pl',
           'cgi' => {
                      'expires' => '+1y',
-                     'cookiePath' => '/',
-                     'serverName' => 'http://localhost',
                      'DocumentRoot' => '/var/www/htdocs/',
                      'bin' => '/var/www/cgi-bin',
                      'style' => 'mysql',
-                     'title' => 'MySQL::Admin'
+                     'title' => 'MySQL::Admin',
+                     'serverName' => 'http://localhost',
+                     'cookiePath' => '/'
                    },
+          'session' => '/var/www/cgi-bin/config/session.pl',
+          'saveTranslate' => '0',
+          'htmlright' => '2',
+          'uploads' => {
+                         'path' => '/var/www/htdocs//download',
+                         'enabled' => 1,
+                         'right' => 2,
+                         'maxlength' => '2100000000000000',
+                         'chmod' => 438
+                       },
+          'version' => '1.02',
           'apacheconfig' => '/etc/apache2/sites-enabled/',
-          'version' => '1.01',
+          'admin' => {
+                       'password' => 'testpass'
+                     },
+          'config' => '/var/www/cgi-bin/config/settings.pl',
+          'files' => {
+                       'chmod' => '0755',
+                       'owner' => 'lze',
+                       'group' => 'lze'
+                     },
+          'database' => {
+                          'CurrentUser' => 'root',
+                          'CurrentDb' => 'MySQLAdmin',
+                          'password' => '',
+                          'host' => 'localhost',
+                          'CurrentHost' => 'localhost',
+                          'name' => 'MySQLAdmin',
+                          'CurrentPass' => '',
+                          'user' => 'root'
+                        },
+          'translate' => '/var/www/cgi-bin/config/translate.pl',
+          'language' => 'en',
+          'mod' => 'n',
+          'news' => {
+                      'messages' => '5',
+                      'right' => 5,
+                      'captcha' => 3
+                    },
           'tree' => {
-                      'links' => '/var/www/cgi-bin/config/links.pl',
-                      'navigation' => '/var/www/cgi-bin/config/tree.pl'
-                    }
+                      'navigation' => '/var/www/cgi-bin/config/tree.pl',
+                      'links' => '/var/www/cgi-bin/config/links.pl'
+                    },
+          'size' => '16',
+          'defaultAction' => 'ShowDatabases'
         };
 $m_hrSettings =$VAR1;
\ No newline at end of file
