@@ -14,7 +14,7 @@ use vars qw(
   $m_nRight
   $m_tbl
   $driver
-  $m_oDatabase
+  $m_sDatabase
   $m_sHost
   $m_sPass
   $m_sUser
@@ -33,7 +33,7 @@ $m_sDefaultClass = 'DBI::Library' unless defined $DBI::Library::m_sDefaultClass;
         qw(quote quote_identifier CurrentPass CurrentUser CurrentHost CurrentDb Driver tableLength tableExists initDB useexecute void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute selectTable)
     ],
 );
-$DBI::Library::VERSION = '1.01';
+$DBI::Library::VERSION = '1.02';
 $m_tbl                 = 'querys';
 $driver                = 'mysql';
 require Exporter;
@@ -165,7 +165,7 @@ sub new {
 sub initDB {
     my ($self, @p) = getSelf(@_);
     my $hash = $p[0];
-    $m_oDatabase =
+    $m_sDatabase =
       defined $hash->{name}
       ? $hash->{name}
       : '%DATABASE%';
@@ -174,7 +174,7 @@ sub initDB {
     $m_sPass = defined $hash->{password} ? $hash->{password} : '';
     my $install = defined $hash->{install} ? $hash->{install} : 0;
     $m_sStyle = defined $hash->{style} ? $hash->{style} : 'mysql';
-    $m_dsn = "DBI:$driver:database=$m_oDatabase;host=$m_sHost";
+    $m_dsn = "DBI:$driver:database=$m_sDatabase;host=$m_sHost";
     $m_dbh = DBI::Library->connect(
         $m_dsn, $m_sUser, $m_sPass,
         {
@@ -186,7 +186,7 @@ sub initDB {
       )
       or warn "$DBI::Library::errs";
     $self->void("SET NAMES 'utf8_general_ci'");
-    if (!$install && $m_oDatabase eq '%DATABASE%') {
+    if (!$install && $m_sDatabase eq '%DATABASE%') {
         my @q = $self->fetch_array('select title from querys');
         $m_hFunctions{$_} = $_ foreach (@q);
     }
@@ -218,7 +218,7 @@ return the current used Database
 =cut
 
 sub CurrentDb {
-    return $m_oDatabase;
+    return $m_sDatabase;
 }
 
 =head2 CurrentHost()
@@ -308,7 +308,7 @@ add sql statments to yourdatabase for later use witdh useexecute();
 
         $database->addexecute(\%execute);
 
-        print join '<br/>' ,$m_oDatabase->showTables();
+        print join '<br/>' ,$m_sDatabase->showTables();
 
 Fo Syntax:
 
@@ -528,7 +528,7 @@ sub void {
       }
     };
     $sth->finish();
-    return "$@" if $@;
+    
 }
 
 =head2 quote()
