@@ -27,7 +27,7 @@ use vars
 @MySQL::Admin::GUI::EXPORT =
   qw( ContentHeader Body ChangeDb Unique openFile action applyRights maxlength);
 @ISA                        = qw( Exporter MySQL::Admin );
-$MySQL::Admin::GUI::VERSION = '1.01';
+$MySQL::Admin::GUI::VERSION = '1.02';
 $m_bMod_perl                = ($ENV{MOD_PERL}) ? 1 : 0;
 local $^W = 0;
 our @m_processlist;
@@ -232,7 +232,10 @@ sub Body {
               if -e "$m_hrSettings->{cgi}{bin}/Content/$action->{file}";
             eval($action->{sub}) if $action->{sub} ne 'main';
             print q|]]></output>|;
-            print qq|<output id="errorMessage"><![CDATA[$@]]></output>| if $@;
+            if($@){
+	      print qq|<output id="errorMessage"><![CDATA[$@]]></output>|;
+	      warn "MySQL::Admin::Body $@  $/"; 
+            }
         } else {
             $exploit = 1;
         }
@@ -241,10 +244,12 @@ sub Body {
         print qq|<output id="content"><![CDATA[|;
         do("$m_hrSettings->{cgi}{bin}/Content/exploit.pl");
         print q|]]></output>|;
-        print qq|<output id="errorMessage"><![CDATA[$@ ]]></output>| if $@;
+	if($@){
+	  print qq|<output id="errorMessage"><![CDATA[$@]]></output>|;
+	  warn "MySQL::Admin::Body $@  $/"; 
+	}
     }
 
-    #     else{#change main Db
     ChangeDb(
              {
               name     => $m_hrSettings->{database}{name},
@@ -254,9 +259,6 @@ sub Body {
              }
             );
 
-    #     }
-    #     clearSession();
-    #
     print '</xml>';
 }
 
